@@ -34,7 +34,9 @@ class OutputAria2(object):
                 entries.
     uri:        URI of file to download. Can include inline Basic Auth para-
                 meters and use jinja2 templating with any fields available
-                in the entry.
+                in the entry. If you are using any of the dynamic renaming
+                options below, the filename can be included in this setting
+                using {{filename}}.
     exclude_samples:
                 [yes|no] Exclude any files that include the word 'sample' in
                 their name. default 'no'
@@ -86,10 +88,24 @@ class OutputAria2(object):
                 command name, and changing key=value to key: value. All
                 options will be treated as jinja2 templates and rendered prior
                 to passing to aria2. default ''
-                Example:
-                aria_config:
-                  dir: "/Volumes/all_my_tv/{{series_name}}"
-                  max-connection-per-server: 4
+
+    Sample configuration:
+    aria2:
+      server: myserver
+      port: 6802
+      do: add-new
+      exclude_samples: yes
+      exclude_non_content: yes
+      parse_filename: yes
+      content_is_episodes: yes
+      rename_content_files: yes
+      rename_template: '{{series_name}} - {{series_id||lower}}'
+      aria_config:
+        max-connection-per-server: 4
+        max-concurrent-downloads: 4
+        split: 4
+        file-allocation: none
+        dir: "/Volumes/all_my_tv/{{series_name}}"
     """
 
     schema = {
@@ -171,30 +187,33 @@ class OutputAria2(object):
                 config['aria_config']['gid'] = entry['aria_gid']
             elif 'torrent_info_hash' in entry:
                 config['aria_config']['gid'] = entry['torrent_info_hash'][0:16]
-            else:
-                config['aria_config']['gid'] = ''
+            elif 'gid' in config['aria_config']:
+                del(config['aria_config']['gid'])
 
             if 'content_files' not in entry:
                 if entry['url']:
                     entry['content_files'] = [entry['url']]
                 else:
                     entry['content_files'] = [entry['title']]
+            else:
+                if not isinstance(entry['content_files'], list):
+                    entry['content_files'] = [entry['content_files']]
 
             counter = 0
-            for curFile in entry['content_files']:
+            for cur_file in entry['content_files']:
 
-                curFilename = curFile.split('/')[-1]
-                if curFile.split('/')[0] != curFilename and config['keep_parent_folders']:
-                    lastSlash = curFile.rfind('/')
-                    curPath = curFile[:lastSlash]
+                cur_filename = cur_file.split('/')[-1]
+                if cur_file.split('/')[0] != cur_filename and config['keep_parent_folders']:
+                    lastSlash = cur_file.rfind('/')
+                    curPath = cur_file[:lastSlash]
                     if curPath[0:1] == '/':
                         curPath = curPath[1:]
                     entry['parent_folders'] = entry['basedir'] + curPath
 
-                fileDot = curFilename.rfind(".")
-                fileExt = curFilename[fileDot:]
+                file_dot = cur_filename.rfind(".")
+                file_ext = cur_filename[file_dot:]
 
-                if len(entry['content_files']) > 1:
+                if len(entry['content_files']) > 1 and 'gid' in config['aria_config']:
                     # if there is more than 1 file, need to give unique gids, this will work up to 999 files
                     counter += 1
                     strCounter = str(counter)
@@ -208,10 +227,10 @@ class OutputAria2(object):
 
                 if config['exclude_samples'] == True:
                     # remove sample files from download list
-                    if curFilename.lower().find('sample') > -1:
+                    if cur_filename.lower().find('sample') > -1:
                         continue
 
-                if fileExt not in config['file_exts']:
+                if file_ext not in config['file_exts']:
                     if config['exclude_non_content'] == True:
                         # don't download non-content files, like nfos - definable in file_exts
                         continue
@@ -220,8 +239,8 @@ class OutputAria2(object):
                     if config['content_is_episodes']:
                         metainfo_series = plugin.get_plugin_by_name('metainfo_series')
                         guess_series = metainfo_series.instance.guess_series
-                        if guess_series(curFilename):
-                            parser = guess_series(curFilename)
+                        if guess_series(cur_filename):
+                            parser = guess_series(cur_filename)
                             entry['series_name'] = parser.name
                             # if the last four chars are numbers, REALLY good chance it's actually a year...
                             # fix it if so desired
@@ -230,7 +249,7 @@ class OutputAria2(object):
                                 entry['series_name'] = ''.join([entry['series_name'][0:-4], '(',
                                                                entry['series_name'][-4:], ')'])
                                 log.verbose(entry['series_name'])
-                            parser.data = curFilename
+                            parser.data = cur_filename
                             parser.parse
                             log.debug(parser.id_type)
                             if parser.id_type == 'ep':
@@ -243,7 +262,7 @@ class OutputAria2(object):
                     else:
                         from flexget.utils.titles.movie import MovieParser
                         parser = MovieParser()
-                        parser.data = curFile
+                        parser.data = cur_file
                         parser.parse()
                         log.info(parser)
                         testname = parser.name
@@ -260,72 +279,81 @@ class OutputAria2(object):
                         entry['year'] = parser.year
                         entry['movie_year'] = parser.year
 
-                if config['rename_content_files'] == True:
+                if config['rename_content_files']:
                     if config['content_is_episodes']:
                         try:
-                            config['aria_config']['out'] = entry.render(config['rename_template']) + fileExt
+                            config['aria_config']['out'] = entry.render(config['rename_template']) + file_ext
                             log.verbose(config['aria_config']['out'])
                         except RenderError as e:
-                            log.error('Could not rename file %s: %s.' % (curFilename, e))
+                            log.error('Could not rename file %s: %s.' % (cur_filename, e))
                             continue
                     else:
                         try:
-                            config['aria_config']['out'] = entry.render(config['rename_template']) + fileExt
+                            config['aria_config']['out'] = entry.render(config['rename_template']) + file_ext
                             log.verbose(config['aria_config']['out'])
                         except RenderError as e:
                             log.error('Could not rename file %s: %s. Try enabling imdb_lookup in this task'
-                                      ' to assist.' % (curFilename, e))
+                                      ' to assist.' % (cur_filename, e))
                             continue
                 else:
-                    config['aria_config']['out'] = curFilename
+                    config['aria_config']['out'] = cur_filename
 
                 if config['do'] == 'add-new':
-                    newDownload = 0
-                    try:
-                        r = s.aria2.tellStatus(config['aria_config']['gid'], ['gid', 'status'])
-                        log.info('Download status for %s (gid %s): %s' % (config['aria_config']['out'], r['gid'],
-                                 r['status']))
-                        if r['status'] == 'paused':
-                            try:
-                                if not task.manager.options.test:
-                                    s.aria2.unpause(r['gid'])
-                                log.info('  Unpaused download.')
-                            except xmlrpclib.Fault as err:
-                                raise plugin.PluginError('aria response to unpause request: %s' % err.faultString, log)
-                        else:
-                            log.info('  Therefore, not re-adding.')
-                    except xmlrpclib.Fault as err:
-                        if err.faultString[-12:] == 'is not found':
-                            newDownload = 1
-                        else:
-                            raise plugin.PluginError('aria response to download status request: %s'
-                                                     % err.faultString, log)
-                    except xmlrpclib.ProtocolError as err:
-                        raise plugin.PluginError('Could not connect to aria2 at %s. Protocol error %s: %s'
-                                                 % (baseurl, err.errcode, err.errmsg), log)
-                    except socket_error as (error, msg):
-                        raise plugin.PluginError('Socket connection issue with aria2 daemon at %s: %s'
-                                                 % (baseurl, msg), log)
+                    new_download = 0
+                    if 'gid' in config['aria_config']:
+                        try:
+                            r = s.aria2.tellStatus(config['aria_config']['gid'], ['gid', 'status'])
+                            log.info('Download status for %s (gid %s): %s' % (config['aria_config']['out'], r['gid'],
+                                     r['status']))
+                            if r['status'] == 'paused':
+                                try:
+                                    if not task.manager.options.test:
+                                        s.aria2.unpause(r['gid'])
+                                    log.info('  Unpaused download.')
+                                except xmlrpclib.Fault as err:
+                                    raise plugin.PluginError('aria response to unpause request: %s' % err.faultString, log)
+                            else:
+                                log.info('  Therefore, not re-adding.')
+                        except xmlrpclib.Fault as err:
+                            if err.faultString[-12:] == 'is not found':
+                                new_download = 1
+                            else:
+                                raise plugin.PluginError('aria response to download status request: %s'
+                                                         % err.faultString, log)
+                        except xmlrpclib.ProtocolError as err:
+                            raise plugin.PluginError('Could not connect to aria2 at %s. Protocol error %s: %s'
+                                                     % (baseurl, err.errcode, err.errmsg), log)
+                        except socket_error as (error, msg):
+                            raise plugin.PluginError('Socket connection issue with aria2 daemon at %s: %s'
+                                                     % (baseurl, msg), log)
+                    else:
+                        new_download = 1
 
-                    if newDownload == 1:
+                    if new_download == 1:
+                        try:
+                            entry['filename'] = cur_file
+                            cur_uri = entry.render(config['uri'])
+                            log.verbose('uri: %s' % cur_uri)
+                        except RenderError as e:
+                            raise plugin.PluginError('Unable to render uri: %s' % e)
                         try:
-                            entry['filename'] = curFile
-                            curUri = entry.render(config['uri'])
                             if not task.manager.options.test:
-                                r = s.aria2.addUri([curUri], dict((key, entry.render(str(value)))
+                                r = s.aria2.addUri([cur_uri], dict((key, entry.render(str(value)))
                                                    for (key, value) in config['aria_config'].iteritems()))
                             else:
-                                if config['aria_config']['gid'] == '':
+                                if 'gid' not in config['aria_config']:
                                     r = '1234567890123456'
                                 else:
                                     r = config['aria_config']['gid']
                             log.info('%s successfully added to aria2 with gid %s.' % (config['aria_config']['out'], r))
-                            log.verbose('uri: %s' % curUri)
                         except xmlrpclib.Fault as err:
                             raise plugin.PluginError('aria response to add URI request: %s' % err.faultString, log)
                         except socket_error as (error, msg):
                             raise plugin.PluginError('Socket connection issue with aria2 daemon at %s: %s'
                                                      % (baseurl, msg), log)
+                        except RenderError as e:
+                            raise plugin.PluginError('Unable to render one of the fields being passed to aria2:'
+                                                     '%s' % e)
 
                 elif config['do'] == 'remove-completed':
                     try:
